@@ -733,7 +733,7 @@ int IOSInterfaces::processDeviceConfig(Device *device, ConfigLine *command, char
 			}
 
 			// cdp
-			else if ((strcmp(command->part(tempInt), "cdp") == 0) && (strcmp(command->part(tempInt + 1), "enable") != 0))
+			else if ((strcmp(command->part(tempInt), "cdp") == 0) && (strcmp(command->part(tempInt + 1), "enable") == 0))
 			{
 				if (device->config->reportFormat == Config::Debug)
 					printf("%sInterface CDP Line:%s %s\n", device->config->COL_GREEN, device->config->COL_RESET, line);
